import pandas as pd


# fields found and their corresponding action
fields: list[list[str]] = [['EchoTime', 'drop'],
                           ['FlipAngle', 'drop'],
                           ['PixelBandwidth', 'drop'],
                           ['PixelSpacing', 'drop'],
                           ['Image Type', 'one_hot_encoding_from_array'],
                           ['Manufacturer', 'one_hot_encoding_from_str_col'],
                           ['Diffusion b-value', 'drop'],
                           ['Diffusion Gradient Orientation', 'drop'],
                           ['Diffusionb-value', 'keep'],
                           ['Diffusionb-valueMax', 'keep'],
                           ['Echo Number(s)', 'keep'],
                           ['Echo Time', 'keep'],
                           ['Echo Train Length', 'keep'],
                           ['Flip Angle', 'keep'],
                           ['Inversion Time', 'keep'],
                           ['Pixel Bandwidth', 'keep'],
                           ['Repetition Time', 'keep'],
                           ['SAR', 'keep'],
                           ['Temporal Resolution', 'drop'],
                           ['Scanning Sequence', 'one_hot_encoding_from_array'],
                           ['Sequence Variant', 'one_hot_encoding_from_array'],
                           ['Scan Options', 'drop'],
                           ['SeriesVolumeCount', 'keep'],
                           ['Pixel Padding Value', 'drop'],
                           ['In-plane Phase Encoding Direction', 'one_hot_encoding_from_str_col'],
                           ['Columns', 'drop'],
                           ['dB/dt', 'keep'],
                           ['Imaged Nucleus', 'drop'],
                           ['Imaging Frequency', 'keep'],
                           ['MR Acquisition Type', 'one_hot_encoding_from_str_col'],
                           ['Number of Averages', 'keep'],
                           ['Samples per Pixel', 'keep'],
                           ['Variable Flip Angle Flag', 'one_hot_encoding_from_str_col'],
                           ['Derivation Description', 'drop'],
                           ['Nominal Interval', 'drop'],
                           ['Time of Secondary Capture', 'drop'],
                           ['[B_value]', 'drop'],
                           ['Number of Temporal Positions', 'drop'],
                           ['FileName', 'keep'],
                           ['Image Orientation (Patient)', 'keep'],
                           ['Contrast/Bolus Agent', 'keep'],
                           ['[NumberOfImagesInMosaic]', 'drop'],
                           ['Series Description', 'drop'],
                           ['SeriesInstanceUID', 'keep'],
                           ['SeriesNumber', 'keep'],
                           ['StudyInstanceUID', 'keep'],
                           ['Angio Flag', 'keep'],
                           ['Slice Thickness', 'keep'],
                           ['[DiffusionGradientDirection]', 'drop'],
                           ['[Slice Orientation]', 'drop'],
                           ['Pixel Spacing', 'keep'],
                           ['Spacing Between Slices', 'keep'],
                           ['Spatial Resolution', 'drop'],
                           ['ImageType', 'drop'],
                           ['ImageTypeADC', 'drop'],
                           ['ImageTypeFA', 'drop'],
                           ['ImageTypeTrace', 'drop'],
                           ["Manufacturer's Model Name", 'drop'],
                           ['ManufacturerCode', 'drop'],
                           ['Study Description', 'drop'],
                           ['Unnamed: 0', 'drop'],
                           ['[A Coord of Bottom Right Corner]', 'drop'],
                           ['[A Coord of Top Right Corner]', 'drop'],
                           ['[Acq recon record checksum]', 'drop'],
                           ['[Acquisition Duration]', 'drop'],
                           ['[Acquisition Number]', 'drop'],
                           ['[AcquisitionMatrixText]', 'drop'],
                           ['[Actual receive gain analog]', 'drop'],
                           ['[Actual receive gain digital]', 'drop'],
                           ['[Actual series data time stamp]', 'drop'],
                           ['[Additional Asset Data]', 'drop'],
                           ['[Advantage comp. Overflow]', 'drop'],
                           ['[Advantage comp. Underflow]', 'drop'],
                           ['[ASSET Acquisition Calibration Series UID]', 'drop'],
                           ['[Asset R Factors]', 'drop'],
                           ['[Auto Prescan Analog receiver gain]', 'drop'],
                           ['[Auto Prescan Center Frequency]', 'drop'],
                           ['[Auto Prescan Digital receiver gain]', 'drop'],
                           ['[Auto Prescan Transmit Gain]', 'drop'],
                           ['[Auto window/level alpha]', 'drop'],
                           ['[Auto window/level beta]', 'drop'],
                           ['[Auto window/level level]', 'drop'],
                           ['[Auto window/level window]', 'drop'],
                           ['[B_matrix]', 'drop'],
                           ['[BandwidthPerPixelPhaseEncode]', 'drop'],
                           ['[Bitmap defining CVs]', 'drop'],
                           ['[Bitmap of prescan options]', 'drop'],
                           ['[Calibrated Field strength]', 'drop'],
                           ['[Cardiac phase number]', 'drop'],
                           ['[Cardiac repetition time]', 'drop'],
                           ['[Cardiac Sync]', 'drop'],
                           ['[Center A coord of plane image]', 'drop'],
                           ['[Center freq. Method]', 'drop'],
                           ['[Center R coord of plane image]', 'drop'],
                           ['[Center S coord of plane image]', 'drop'],
                           ['[Chemical Shift Number MR]', 'drop'],
                           ['[Chemical Shift]', 'drop'],
                           ['[Coil ID Data]', 'drop'],
                           ['[CoilString]', 'drop'],
                           ['[Concatenated SAT {# DTI Diffusion Dir., release 9.0 & below}]', 'drop'],
                           ['[Content Qualification]', 'drop'],
                           ['[Contiguous]', 'drop'],
                           ['[CSA Image Header Type]', 'drop'],
                           ['[CSA Image Header Version ??]', 'drop'],
                           ['[CSA Image Header Version]', 'drop'],
                           ['[CSA Series Header Type]', 'drop'],
                           ['[CSA Series Header Version]', 'drop'],
                           ['[dB/dt Limits in units of percent]', 'drop'],
                           ['[DB/dt Peak rate of change of gradient field]', 'drop'],
                           ['[Deferred Validation]', 'drop'],
                           ['[Delay after trigger]', 'drop'],
                           ['[Diffusion B-Factor]', 'drop'],
                           ['[Diffusion Direction AP]', 'drop'],
                           ['[Diffusion Direction FH]', 'drop'],
                           ['[Diffusion Direction RL]', 'drop'],
                           ['[Diffusion direction]', 'drop'],
                           ['[Diffusion Direction]', 'drop'],
                           ['[Diffusion Echo Time]', 'drop'],
                           ['[DiffusionDirectionality]', 'drop'],
                           ['[Display field of view]', 'drop'],
                           ['[Dynamic Series]', 'drop'],
                           ['[Echo Time Display MR]', 'drop'],
                           ['[Echo Train Length]', 'drop'],
                           ['[Effective echo spacing]', 'drop'],
                           ['[EPI Factor]', 'drop'],
                           ['[Equipment UID]', 'drop'],
                           ['[Exam Record checksum]', 'drop'],
                           ['[Examination Source]', 'drop'],
                           ['[Extremity Coil flag]', 'drop'],
                           ['[Fast phases]', 'drop'],
                           ['[Filter Mode (String slop field 1 in legacy GE MR]', 'drop'],
                           ['[First scan location]', 'drop'],
                           ['[First scan ras]', 'drop'],
                           ['[Flip Angle Philips]', 'drop'],
                           ['[FlowCompensation]', 'drop'],
                           ['[FMRIStimulInfo]', 'drop'],
                           ['[Foreign Image Revision]', 'drop'],
                           ['[Fps]', 'drop'], ['[Fractional echo]', 'drop'], ['[Full fidelity]', 'drop'], ['[GE Coil Name]', 'drop'], ['[GE image integrity]', 'drop'], ['[Genesis Version - now]', 'drop'], ['[Genesis version - Now]', 'drop'], ['[Governing Body, dB/dt, and SAR definition]', 'drop'], ['[Gradient offset in X]', 'drop'], ['[Gradient offset in Y]', 'drop'], ['[Gradient offset in Z]', 'drop'], ['[GradientMode]', 'drop'], ['[Graphically prescribed]', 'drop'], ['[Horiz. Frame of ref.]', 'drop'], ['[ImaAbsTablePosition]', 'drop'], ['[Image actual date]', 'drop'], ['[Image archive flag]', 'drop'], ['[Image dimension - X]', 'drop'], ['[Image dimension - Y]', 'drop'], ['[Image Enhanced]', 'drop'], ['[Image Filtering 0.5/0.2T]', 'drop'], ['[Image Filtering Parameters]', 'drop'], ['[Image from which prescribed]', 'drop'], ['[Image location]', 'drop'], ['[Image Type (real, imaginary, phase, magnitude)]', 'drop'], ['[Image Type ED ES]', 'drop'], ['[Imaged Nucleus]', 'drop'], ['[Images in Series]', 'drop'], ['[Images per cardiac cycle]', 'drop'], ['[Imaging Frequency]', 'drop'], ['[Imaging Mode]', 'drop'], ['[Imaging Options]', 'drop'], ['[ImaRelTablePosition]', 'drop'], ['[Indicates no. of updates to header]', 'drop'], ['[Indicates study has complete info (DICOM/genesis)]', 'drop'], ['[Institution Code]', 'drop'], ['[Interactive]', 'drop'], ['[Internal Pulse Sequence Name]', 'drop'], ['[Inversion Time]', 'drop'], ['[Landmark Counter]', 'drop'], ['[Last image number used]', 'drop'], ['[Last pseq]', 'drop'], ['[Last pulse sequence used]', 'drop'], ['[Last scan loc]', 'drop'], ['[Last scan ras]', 'drop'], ['[Level value]', 'drop'], ['[Locations in acquisition]', 'drop'], ['[Locs per 3D slab]', 'drop'], ['[Lower range of Pixels1]', 'drop'], ['[Lower range of Pixels2]', 'drop'], ['[Magnetic Field Strength]', 'drop'], ['[MedCom OOG Type]', 'drop'], ['[MedCom OOG Version]', 'drop'], ['[Mobile location number]', 'drop'], ['[Monitor SAR]', 'drop'], ['[MosaicRefAcqTimes]', 'drop'], ['[Neg_scanspacing]', 'drop'], ['[NEW/SEEN Status]', 'drop'], ['[No. of updates to header]', 'drop'], ['[None, None, None, None, None, None, None, None, None, None', 'drop'], ['[Normal A coord]', 'drop'], ['[Normal R coord]', 'drop'], ['[Normal S coord]', 'drop'], ['[Num 3D slabs]', 'drop'], ['[Number of Acquisitions]', 'drop'], ['[Number of Averages]', 'drop'], ['[Number of Chemical Shift]', 'drop'], ['[Number of Dynamic Scans]', 'drop'], ['[Number of echoes]', 'drop'], ['[Number of Echoes]', 'drop'], ['[Number of EPI shots]', 'drop'], ['[Number of Excitations]', 'drop'], ['[Number of images archived]', 'drop'], ['[Number of Locations]', 'drop'], ['[Number of PC Directions]', 'drop'], ['[Number of Phases MR]', 'drop'], ['[Number of Slices MR]', 'drop'], ['[Number of Stacks]', 'drop'], ['[Oblique Plane]', 'drop'], ['[Offset Frequency]', 'drop'], ['[Overlaps]', 'drop'], ['[Partial Matrix Scanned]', 'drop'], ['[Patient Status]', 'drop'], ["[Patient's Name]", 'drop'], ['[PATModeText]', 'drop'], ['[Pause Interval]', 'drop'], ['[Pause Time]', 'drop'], ['[PC Velocity]', 'drop'], ['[Peak SAR]', 'drop'], ['[Phase Contrast flow axis]', 'drop'], ['[Phase FOV Percent]', 'drop'], ['[Phase Number]', 'drop'], ['[Plane Type]', 'drop'], ['[PMTF Information 1]', 'drop'], ['[PMTF Information 2]', 'drop'], ['[PMTF Information 3]', 'drop'], ['[PMTF Information 4]', 'drop'], ['[PositivePCSDirections]', 'drop'], ['[Prepulse Delay]', 'drop'], ['[Prepulse Type]', 'drop'], ['[Prescan Reuse String]', 'drop'], ['[Prescan status]', 'drop'], ['[Prescan type]', 'drop'], ['[Primary Receiver Suite and Host]', 'drop'], ['[Private Creator]', 'drop'], ['[Private In-Plane Phase Encoding Direction]', 'drop'], ['[Product id]', 'drop'], ['[Projection Algorithm Name]', 'drop'], ['[Projection Algorithm]', 'drop'], ['[Projection angle]', 'drop'], ['[Prospective Motion Correction]', 'drop'], ['[PSD estimated limit in tesla per second]', 'drop'], ['[PSD estimated limit]', 'drop'], ['[Pulse Sequence Date]', 'drop'], ['[Pulse Sequence Mode]', 'drop'], ['[Pulse Sequence Name]', 'drop'], ['[Pulse Sequence]', 'drop'], ['[PURE Acquisition Calibration Series UID]', 'drop'], ['[R Coord of Bottom Right Corner]', 'drop'], ['[R Coord of Top Right Corner]', 'drop'], ['[RAS letter of image location]', 'drop'], ['[Raw data run number]', 'drop'], ['[RBMoCoRot]', 'drop'], ['[RBMoCoTrans]', 'drop'], ['[RealDwellTime]', 'drop'], ['[Reason for Study]', 'drop'], ['[Receive Date]', 'drop'], ['[Receive Origin Description]', 'drop'], ['[Receive Origin]', 'drop'], ['[Receive Time]', 'drop'], ['[Recon mode flag word]', 'drop'], ['[Reconstruction Number MR]', 'drop'], ["[Referring Physician's Name]", 'drop'], ['[Repetition Time]', 'drop'], ["[Requesting Physician's Name]", 'drop'], ['[Respiration Sync]', 'drop'], ['[Respiratory rate, bpm]', 'drop'], ['[Respiratory trigger point]', 'drop'], ['[Rotation from source x rot]', 'drop'], ['[Rotation from source y rot]', 'drop'], ['[Rotation from source z rot]', 'drop'], ['[RTIA_timer]', 'drop'], ['[Rx Stack Identification]', 'drop'], ['[S Coord of Bottom Right Corner]', 'drop'], ['[S Coord of Top Right Corner]', 'drop'], ['[Sampling Percent]', 'drop'], ['[SAR Definition]', 'drop'], ['[SAR value]', 'drop'], ['[Saravghead]', 'drop'], ['[SAT fat/water/bone]', 'drop'], ['[SAT location A]', 'drop'], ['[SAT location F]', 'drop'], ['[SAT location H]', 'drop'], ['[SAT location L]', 'drop'], ['[SAT location P]', 'drop'], ['[SAT location R]', 'drop'], ['[SAT thickness A/P]', 'drop'], ['[SAT thickness H/F]', 'drop'], ['[SAT thickness R/L]', 'drop'], ['[Saturation planes]', 'drop'], ['[Scanner Study Entity UID]', 'drop'], ['[Scanner Study ID]', 'drop'], ['[Scanner Table Entry (single gradient coil', 'drop'], ['[Scanning Technique Description MR]', 'drop'], ['[Scout Type]', 'drop'], ['[Screen Format]', 'drop'], ['[Second echo]', 'drop'], ['[Series Complete Flag]', 'drop'], ['[Series contrast]', 'drop'], ['[Series from which Prescribed]', 'drop'], ['[Series from which prescribed]', 'drop'], ['[Series Owner]', 'drop'], ['[Series plane]', 'drop'], ['[Series Record checksum]', 'drop'], ['[Series Type]', 'drop'], ['[Series Workflow Status]', 'drop'], ['[Service id]', 'drop'], ['[Slice Number MR]', 'drop'], ['[Slice offset on freq axis]', 'drop'], ['[SliceMeasurementDuration]', 'drop'], ['[SlicePosition_PCS]', 'drop'], ['[SliceResolution]', 'drop'], ['[Slop_int_10...slop_int_17]', 'drop'], ['[Slop_int_6... slop_int_9]', 'drop'], ['[Source AE]', 'drop'], ['[SPIR]', 'drop'], ['[Start time(secs) in first axial]', 'drop'], ['[String slop field 2]', 'drop'], ['[Study Description]', 'drop'], ['[Suite id]', 'drop'], ['[Surface coil intensity]', 'drop'], ['[Surface Coil Type]', 'drop'], ['[Swappf]', 'drop'], ['[Syncra Scan Type]', 'drop'], ['[System Configuration Information]', 'drop'], ['[Table delta]', 'drop'], ['[TablePositionOrigin]', 'drop'], ['[Tag Spacing]', 'drop'], ['[Tagging Flip Angle]', 'drop'], ['[Tagging Orientation]', 'drop'], ['[Tamar Exe Software Version]', 'drop'], ['[Tamar Site Id]', 'drop'], ['[Tamar Study Age]', 'drop'], ['[Tamar Study Body Part]', 'drop'], ['[Tamar Study Has Sticky Note]', 'drop'], ['[Tamar Study Status]', 'drop'], ['[Tamar Translate Flags]', 'drop'], ['[Thickness disclaimer]', 'drop'], ['[TimeAfterStart]', 'drop'], ['[Transmit gain]', 'drop'], ['[Transmitting Coil Type]', 'drop'], ['[Type of receiver used]', 'drop'], ['[Unknown]', 'drop'], ['[Upper range of Pixels1]', 'drop'], ['[Upper range of Pixels2]', 'drop'], ['[User data 0]', 'drop'], ['[User data 1]', 'drop'], ['[User data 10]', 'drop'], ['[User data 11]', 'drop'], ['[User data 12]', 'drop'], ['[User data 13]', 'drop'], ['[User data 14]', 'drop'], ['[User data 15]', 'drop'], ['[User data 16]', 'drop'], ['[User data 17]', 'drop'], ['[User data 18]', 'drop'], ['[User data 19]', 'drop'], ['[User data 2]', 'drop'], ['[User data 20]', 'drop'], ['[User data 21]', 'drop'], ['[User data 22]', 'drop'], ['[User data 23 {# DTI Diffusion Dir., release 9.0 & below}]', 'drop'], ['[User data 24 {# DTI Diffusion Dir., release 10.0 & above}]', 'drop'], ['[User data 25...User data 48 {User48=Effective Resolution for spiral}]', 'drop'], ['[User data 3]', 'drop'], ['[User data 4]', 'drop'], ['[User data 5]', 'drop'], ['[User data 6]', 'drop'], ['[User data 7]', 'drop'], ['[User data 8]', 'drop'], ['[User data 9]', 'drop'], ['[User_fill_map_LSW]', 'drop'], ['[User_fill_map_MSW]', 'drop'], ['[User_usage_tag]', 'drop'], ['[Variable echoflag]', 'drop'], ['[Vas collapse flag]', 'drop'], ['[Vas flags]', 'drop'], ['[Velocity Encode Scale]', 'drop'], ['[Velocity encoding]', 'drop'], ['[Version of the hdr struct]', 'drop'], ['[Views per segment]', 'drop'], ['[Water Fat Shift]', 'drop'], ['[Window Center]', 'drop'], ['[Window value]', 'drop'], ['[Window Width]', 'drop'], ['Accession Number', 'drop'], ['Acquisition Matrix', 'drop'], ['Acquisition Number', 'drop'], ['Actual Frame Duration', 'drop'], ['Bits Allocated', 'drop'], ['Bits Stored', 'drop'], ['Blue Palette Color Lookup Table Descriptor', 'drop'], ['Body Part Examined', 'drop'], ['Cardiac Number of Images', 'drop'], ['Code Value', 'drop'], ['Coding Scheme Designator', 'drop'], ['Collimator Type', 'drop'], ['Concatenation UID', 'drop'], ['Content Time', 'drop'], ['Contrast/Bolus Ingredient', 'drop'], ['Contrast/Bolus Ingredient Concentration', 'drop'], ['Contrast/Bolus Total Dose', 'drop'], ['Contrast/Bolus Volume', 'drop'], ['Conversion Type', 'drop'], ['Convolution Kernel', 'drop'], ['Corrected Image', 'drop'], ['Counts Source', 'drop'], ['Date of Last Calibration', 'drop'], ['Date of Secondary Capture', 'drop'], ['Decay Correction', 'drop'], ['Decay Factor', 'drop'], ['Diffusionb-valueCount', 'drop'], ['Diffusionb-valueMin', 'drop'], ['Diffusionb-valueSet', 'drop'], ['Filler Order Number / Imaging Service Request (Retired)', 'drop'], ['Frame of Reference UID', 'drop'], ['Frame Reference Time', 'drop'], ['Green Palette Color Lookup Table Descriptor', 'drop'], ['Group Length', 'drop'], ['HasDiffusionGradientOrientation', 'drop'], ['High Bit', 'drop'], ['High R-R Value', 'drop'], ['Image Frame Origin', 'drop'], ['Image Index', 'drop'], ['Image Orientation', 'drop'], ['Image Position', 'drop'], ['Image Position (Patient)', 'drop'], ['ImageOrientationPatient', 'drop'], ['ImageOrientationPatient_0', 'drop'], ['ImageOrientationPatient_1', 'drop'], ['ImageOrientationPatient_2', 'drop'], ['ImageOrientationPatient_3', 'drop'], ['ImageOrientationPatient_4', 'drop'], ['ImageOrientationPatient_5', 'drop'], ['Instance Creation Date', 'drop'], ['Intervals Acquired', 'drop'], ['Intervals Rejected', 'drop'], ['IsDerivedImageType', 'drop'], ['Largest Image Pixel Value', 'drop'], ['Laterality', 'drop'], ['list_of_ordered_volume_files', 'drop'], ['Low R-R Value', 'drop'], ['Magnetic Field Strength', 'drop'], ['Modality', 'drop'], ['MR Acquisition Phase Encoding Steps out-of-plane', 'drop'], ['Names of Intended Recipients of Results', 'drop'], ['Number of Frames in Overlay', 'drop'], ['Number of Phase Encoding Steps', 'drop'], ['Number of Slices', 'drop'], ['Number of Study Related Instances', 'drop'], ['Number of Time Slices', 'drop'], ['Order Entered By', 'drop'], ['Overlay Bit Position', 'drop'], ['Overlay Bits Allocated', 'drop'], ['Overlay Columns', 'drop'], ['Overlay Description', 'drop'], ['Overlay Origin', 'drop'], ['Overlay Rows', 'drop'], ['Overlay Type', 'drop'], ['Palette Color Lookup Table UID', 'drop'], ['Patient Orientation', 'drop'], ['Percent Phase Field of View', 'drop'], ['Percent Sampling', 'drop'], ['Performed Procedure Step Description', 'drop'], ['Performed Procedure Step ID', 'drop'], ['Performed Procedure Step Status', 'drop'], ['Performed Procedure Type Description', 'drop'], ['Photometric Interpretation', 'drop'], ['Pixel Aspect Ratio', 'drop'], ['Pixel Representation', 'drop'], ['PixelSpacingMax', 'drop'], ['PixelSpacingMin', 'drop'], ['Placer Order Number / Imaging Service Request (Retired)', 'drop'], ['Planar Configuration', 'drop'], ['Position Reference Indicator', 'drop'], ['Presentation LUT Shape', 'drop'], ['Private Creator', 'drop'], ['Protocol Name', 'drop'], ['Randoms Correction Method', 'drop'], ['Receive Coil Name', 'drop'], ['Reconstruction Diameter', 'drop'], ['Red Palette Color Lookup Table Descriptor', 'drop'], ['RepetitionTime', 'drop'], ['Requested Contrast Agent', 'drop'], ['Requested Procedure Comments', 'drop'], ['Requested Procedure ID', 'drop'], ['Requested Procedure Location', 'drop'], ['Requested Procedure Priority', 'drop'], ['Requesting Service', 'drop'], ['Rescale Intercept', 'drop'], ['Rescale Slope', 'drop'], ['Rescale Type', 'drop'], ['Rows', 'drop'], ['Scatter Correction Method', 'drop'], ['Sequence Name', 'drop'], ['Series Type', 'drop'], ['Smallest Image Pixel Value', 'drop'], ['Software Versions', 'drop'], ['SOP Class UID', 'drop'], ['Special Needs', 'drop'], ['Specific Character Set', 'drop'], ['Stack ID', 'drop'], ['Study Comments', 'drop'], ['Study Priority ID', 'drop'], ['Study Read Date', 'drop'], ['Study Read Time', 'drop'], ['Study Status ID', 'drop'], ['Synchronization Frame of Reference UID', 'drop'], ['Time of Last Calibration', 'drop'], ['Transmit Coil Name', 'drop'], ['Trigger Window', 'drop'], ['Units', 'drop'], ['Window Center', 'drop'], ['Window Width', 'drop']]


header_df: pd.DataFrame = pd.DataFrame(fields, columns=["header_name", "action"])


def get_header_df() -> pd.DataFrame:
    return header_df
